| eyelinker-package | R Documentation |
Dealing with unprocessed ASC files from EyeLink eye trackers can be a pain. This package aims to make importing and working with these files as fast and easy as possible.
For documentation of the structure of the returned data, see the "format" vignette:
vignette("format", package = "eyelinker")
For worked examples illustrating the package in action, see the "basics", "epoching", and "batch_import" vignettes:
vignette("basics", package = "eyelinker")
vignette("epoching", package = "eyelinker")
vignette("batch_import", package = "eyelinker")
Maintainer: Austin Hurst austin.hurst@dal.ca
Authors:
Simon Barthelmé simon.barthelme@gipsa-lab.fr
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.