Learn R Programming

eyelinker (version 0.2.2)

eyelinker-package: Import ASC Files from EyeLink Eye Trackers

Description

Dealing with unprocessed ASC files from EyeLink eye trackers can be a pain. This package aims to make importing and working with these files as fast and easy as possible.

Arguments

Author

Maintainer: Austin Hurst austin.hurst@dal.ca

Authors:

Details

For documentation of the structure of the returned data, see the "format" vignette:

  • vignette("format", package = "eyelinker")

For worked examples illustrating the package in action, see the "basics", "epoching", and "batch_import" vignettes:

  • vignette("basics", package = "eyelinker")

  • vignette("epoching", package = "eyelinker")

  • vignette("batch_import", package = "eyelinker")

See Also